==> jc-1.4.0.tar.gz: javax/imageio/spi/ImageTranscoderSpi.h <==
// public abstract class javax.imageio.spi.ImageTranscoderSpi

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3de402a610fa78c4 javax_imageio_spi_IIOServiceProvider
// @dep_class 2956a885263d8cd4 javax_imageio_spi_ImageTranscoderSpi

// header file dependencies
// @dep_header javax_imageio_spi_IIOServiceProvider

#include "javax/imageio/spi/IIOServiceProvider.h"

#ifndef _JC_javax_imageio_spi_ImageTranscoderSpi_H_
#define _JC_javax_imageio_spi_ImageTranscoderSpi_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_imageio_ImageTranscoder$object;

// Typedefs
typedef struct _jc_javax_imageio_spi_ImageTranscoderSpi$sub_refs	_jc_javax_imageio_spi_ImageTranscoderSpi$sub_refs;
typedef struct _jc_javax_imageio_spi_ImageTranscoderSpi$sub_nonrefs	_jc_javax_imageio_spi_ImageTranscoderSpi$sub_nonrefs;
typedef struct _jc_javax_imageio_spi_ImageTranscoderSpi$refs	_jc_javax_imageio_spi_ImageTranscoderSpi$refs;
typedef struct _jc_javax_imageio_spi_ImageTranscoderSpi$nonrefs	_jc_javax_imageio_spi_ImageTranscoderSpi$nonrefs;
typedef struct _jc_javax_imageio_spi_ImageTranscoderSpi$object	_jc_javax_imageio_spi_ImageTranscoderSpi$object;

typedef const struct _jc_javax_imageio_spi_ImageTranscoderSpi$vmethods	_jc_javax_imageio_spi_ImageTranscoderSpi$vmethods;
typedef const struct _jc_javax_imageio_spi_ImageTranscoderSpi$vtable	_jc_javax_imageio_spi_ImageTranscoderSpi$vtable;
typedef const struct _jc_javax_imageio_spi_ImageTranscoderSpi$vtype	_jc_javax_imageio_spi_ImageTranscoderSpi$vtype;

// Constructors
extern void _jc_javax_imageio_spi_ImageTranscoderSpi$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_imageio_spi_ImageTranscoderSpi$object *);
extern void _jc_javax_imageio_spi_ImageTranscoderSpi$method$_init$a34354cd9552963f(_jc_env *, struct _jc_javax_imageio_spi_ImageTranscoderSpi$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_object *_jc_javax_imageio_spi_ImageTranscoderSpi$method$createTranscoderInstance$c54937715a7722be(_jc_env *, struct _jc_javax_imageio_spi_ImageTranscoderSpi$object *);
extern struct _jc_java_lang_String$object *_jc_javax_imageio_spi_ImageTranscoderSpi$method$getReaderServiceProviderName$7913c714bc1d2074(_jc_env *, struct _jc_javax_imageio_spi_ImageTranscoderSpi$object *);
extern struct _jc_java_lang_String$object *_jc_javax_imageio_spi_ImageTranscoderSpi$method$getWriterServiceProviderName$7b31eac4b13e177f(_jc_env *, struct _jc_javax_imageio_spi_ImageTranscoderSpi$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_imageio_spi_ImageTranscoderSpi$method_info$createTranscoderInstance$c54937715a7722be;
extern _jc_method _jc_javax_imageio_spi_ImageTranscoderSpi$method_info$getReaderServiceProviderName$7913c714bc1d2074;
extern _jc_method _jc_javax_imageio_spi_ImageTranscoderSpi$method_info$getWriterServiceProviderName$7b31eac4b13e177f;

// Virtual methods structure
struct _jc_javax_imageio_spi_ImageTranscoderSpi$vmethods {
	struct _jc_object	*(*createTranscoderInstance$c54937715a7722be)(_jc_env *, struct _jc_javax_imageio_spi_ImageTranscoderSpi$object *);
	struct _jc_java_lang_String$object	*(*getReaderServiceProviderName$7913c714bc1d2074)(_jc_env *, struct _jc_javax_imageio_spi_ImageTranscoderSpi$object *);
	struct _jc_java_lang_String$object	*(*getWriterServiceProviderName$7b31eac4b13e177f)(_jc_env *, struct _jc_javax_imageio_spi_ImageTranscoderSpi$object *);
};

// Vtable
struct _jc_javax_imageio_spi_ImageTranscoderSpi$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_imageio_spi_IIOServiceProvider$vmethods	javax_imageio_spi_IIOServiceProvider;
	_jc_javax_imageio_spi_ImageTranscoderSpi$vmethods	javax_imageio_spi_ImageTranscoderSpi;
};

// Vtype
struct _jc_javax_imageio_spi_ImageTranscoderSpi$vtype {
	_jc_type			type;
	_jc_javax_imageio_spi_ImageTranscoderSpi$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_imageio_spi_ImageTranscoderSpi$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_imageio_spi_ImageTranscoderSpi$refs {
    _jc_javax_imageio_spi_ImageTranscoderSpi$sub_refs	javax_imageio_spi_ImageTranscoderSpi;
    _jc_javax_imageio_spi_IIOServiceProvider$sub_refs	javax_imageio_spi_IIOServiceProvider;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_imageio_spi_ImageTranscoderSpi$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_imageio_spi_ImageTranscoderSpi$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_imageio_spi_IIOServiceProvider$sub_nonrefs	javax_imageio_spi_IIOServiceProvider;
    _jc_javax_imageio_spi_ImageTranscoderSpi$sub_nonrefs	javax_imageio_spi_ImageTranscoderSpi;
};

// Object instance structure
struct _jc_javax_imageio_spi_ImageTranscoderSpi$object {
	_jc_javax_imageio_spi_ImageTranscoderSpi$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_imageio_spi_ImageTranscoderSpi$vtype	*vtype;
	_jc_javax_imageio_spi_ImageTranscoderSpi$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_imageio_spi_ImageTranscoderSpi$vtype _jc_javax_imageio_spi_ImageTranscoderSpi$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_imageio_spi_ImageTranscoderSpi, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_imageio_spi_ImageTranscoderSpi$class_object;

#endif	/* _JC_javax_imageio_spi_ImageTranscoderSpi_H_ */

==> jc-1.4.6.tar.gz: javax/imageio/spi/ImageTranscoderSpi.h <==
// public abstract class javax.imageio.spi.ImageTranscoderSpi

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3de402a610fa78c4 javax_imageio_spi_IIOServiceProvider
// @dep_class 2956a885263d8cd4 javax_imageio_spi_ImageTranscoderSpi

// header file dependencies
// @dep_header javax_imageio_spi_IIOServiceProvider

#include "javax/imageio/spi/IIOServiceProvider.h"

#ifndef _JC_javax_imageio_spi_ImageTranscoderSpi_H_
#define _JC_javax_imageio_spi_ImageTranscoderSpi_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_imageio_ImageTranscoder$object;

// Typedefs
typedef struct _jc_javax_imageio_spi_ImageTranscoderSpi$sub_refs	_jc_javax_imageio_spi_ImageTranscoderSpi$sub_refs;
typedef struct _jc_javax_imageio_spi_ImageTranscoderSpi$sub_nonrefs	_jc_javax_imageio_spi_ImageTranscoderSpi$sub_nonrefs;
typedef struct _jc_javax_imageio_spi_ImageTranscoderSpi$refs	_jc_javax_imageio_spi_ImageTranscoderSpi$refs;
typedef struct _jc_javax_imageio_spi_ImageTranscoderSpi$nonrefs	_jc_javax_imageio_spi_ImageTranscoderSpi$nonrefs;
typedef struct _jc_javax_imageio_spi_ImageTranscoderSpi$object	_jc_javax_imageio_spi_ImageTranscoderSpi$object;

typedef const struct _jc_javax_imageio_spi_ImageTranscoderSpi$vmethods	_jc_javax_imageio_spi_ImageTranscoderSpi$vmethods;
typedef const struct _jc_javax_imageio_spi_ImageTranscoderSpi$vtable	_jc_javax_imageio_spi_ImageTranscoderSpi$vtable;
typedef const struct _jc_javax_imageio_spi_ImageTranscoderSpi$vtype	_jc_javax_imageio_spi_ImageTranscoderSpi$vtype;

// Constructors
extern void _jc_javax_imageio_spi_ImageTranscoderSpi$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_imageio_spi_ImageTranscoderSpi$object *) _JC_JCNI_ATTR;
extern void _jc_javax_imageio_spi_ImageTranscoderSpi$method$_init$a34354cd9552963f(_jc_env *, struct _jc_javax_imageio_spi_ImageTranscoderSpi$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_javax_imageio_spi_ImageTranscoderSpi$method$createTranscoderInstance$c54937715a7722be(_jc_env *, struct _jc_javax_imageio_spi_ImageTranscoderSpi$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_imageio_spi_ImageTranscoderSpi$method$getReaderServiceProviderName$7913c714bc1d2074(_jc_env *, struct _jc_javax_imageio_spi_ImageTranscoderSpi$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_imageio_spi_ImageTranscoderSpi$method$getWriterServiceProviderName$7b31eac4b13e177f(_jc_env *, struct _jc_javax_imageio_spi_ImageTranscoderSpi$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_imageio_spi_ImageTranscoderSpi$method_info$createTranscoderInstance$c54937715a7722be;
extern _jc_method _jc_javax_imageio_spi_ImageTranscoderSpi$method_info$getReaderServiceProviderName$7913c714bc1d2074;
extern _jc_method _jc_javax_imageio_spi_ImageTranscoderSpi$method_info$getWriterServiceProviderName$7b31eac4b13e177f;

// Virtual methods structure
struct _jc_javax_imageio_spi_ImageTranscoderSpi$vmethods {
	struct _jc_object	*(*createTranscoderInstance$c54937715a7722be)(_jc_env *, struct _jc_javax_imageio_spi_ImageTranscoderSpi$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getReaderServiceProviderName$7913c714bc1d2074)(_jc_env *, struct _jc_javax_imageio_spi_ImageTranscoderSpi$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getWriterServiceProviderName$7b31eac4b13e177f)(_jc_env *, struct _jc_javax_imageio_spi_ImageTranscoderSpi$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_imageio_spi_ImageTranscoderSpi$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_imageio_spi_IIOServiceProvider$vmethods	javax_imageio_spi_IIOServiceProvider;
	_jc_javax_imageio_spi_ImageTranscoderSpi$vmethods	javax_imageio_spi_ImageTranscoderSpi;
};

// Vtype
struct _jc_javax_imageio_spi_ImageTranscoderSpi$vtype {
	_jc_type			type;
	_jc_javax_imageio_spi_ImageTranscoderSpi$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_imageio_spi_ImageTranscoderSpi$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_imageio_spi_ImageTranscoderSpi$refs {
    _jc_javax_imageio_spi_ImageTranscoderSpi$sub_refs	javax_imageio_spi_ImageTranscoderSpi;
    _jc_javax_imageio_spi_IIOServiceProvider$sub_refs	javax_imageio_spi_IIOServiceProvider;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_imageio_spi_ImageTranscoderSpi$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_imageio_spi_ImageTranscoderSpi$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_imageio_spi_IIOServiceProvider$sub_nonrefs	javax_imageio_spi_IIOServiceProvider;
    _jc_javax_imageio_spi_ImageTranscoderSpi$sub_nonrefs	javax_imageio_spi_ImageTranscoderSpi;
};

// Object instance structure
struct _jc_javax_imageio_spi_ImageTranscoderSpi$object {
	_jc_javax_imageio_spi_ImageTranscoderSpi$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_imageio_spi_ImageTranscoderSpi$vtype	*vtype;
	_jc_javax_imageio_spi_ImageTranscoderSpi$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_imageio_spi_ImageTranscoderSpi$vtype _jc_javax_imageio_spi_ImageTranscoderSpi$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_imageio_spi_ImageTranscoderSpi, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_imageio_spi_ImageTranscoderSpi$class_object;

#endif	/* _JC_javax_imageio_spi_ImageTranscoderSpi_H_ */
